/**
 * The hash formats allowed by Packwiz.
 */
export enum HashFormat {
  /**
   * SHA-256 hash format.
   */
  "sha256" = "sha256",
  /**
   * SHA-512 hash format.
   */
  "sha512" = "sha512",
  /**
   * SHA-1 hash format.
   */
  "sha1" = "sha1",
  /**
   * MD5 hash format.
   */
  "md5" = "md5",
  /**
   * Murmur2 hash format.
   * This is a proprietary hash format used by CurseForge.
   */
  "murmur2" = "murmur2",
}

/**
 * Checks if the provided hash format is allowed by Packwiz.
 * @param hashFormat - The hash format to check.
 * @returns The HashFormat enum value if valid, otherwise throws an error.
 */
export function isValidHashFormat(hashFormat: string): HashFormat {
  if (hashFormat in HashFormat) {
    return HashFormat[hashFormat as keyof typeof HashFormat];
  } else {
    throw new Error(`Invalid index file hash format: ${hashFormat}`);
  }
}
